@@ -14,7 +14,7 @@ import pathlib
 import re
 import uuid
 import warnings
-from datetime import datetime
+from datetime import datetime, timezone
 
 from typing import Any, Awaitable, Callable, Dict, Optional, TypeVar, Union, cast
 
@@ -98,7 +98,7 @@ class AMQPBaseActor(AMQPClient, BaseActor):
 
         if ack:
             async with message.process():
-                headers = message.info()["headers"]
+                headers = message.info().get("headers", {})
                 command_body = json.loads(message.body.decode())
         else:
             headers = message.info().get("headers", {})
@@ -107,6 +107,7 @@ class AMQPBaseActor(AMQPClient, BaseActor):
         commander_id = headers.get("commander_id", None)
         command_id = headers.get("command_id", None)
         internal = headers.get("internal", False)
+        write_to_log = headers.get("write_to_log", True)
 
         command_string = command_body.get("command_string", "")
         full_command_string = f"{self.name} {command_string}"
@@ -119,6 +120,7 @@ class AMQPBaseActor(AMQPClient, BaseActor):
                 consumer_id=self.name,
                 actor=self,
                 internal=internal,
+                write_to_log=write_to_log,
             )
             command.actor = self  # Assign the actor
         except CommandError as ee:
@@ -131,10 +133,11 @@ class AMQPBaseActor(AMQPClient, BaseActor):
             )
             return
 
-        self.log.info(
-            f"New command received: {full_command_string!r} "
-            f"(commander_id={commander_id!r}, command_id={command_id!r})"
-        )
+        if write_to_log and self.log:
+            self.log.info(
+                f"New command received: {full_command_string!r} "
+                f"(commander_id={commander_id!r}, command_id={command_id!r})"
+            )
 
         return self.parse_command(command)
 
@@ -186,7 +189,7 @@ class AMQPBaseActor(AMQPClient, BaseActor):
                     content_type="text/json",
                     headers=headers,
                     correlation_id=str(command_id) if command_id is not None else None,
-                    timestamp=datetime.utcnow(),
+                    timestamp=datetime.now(timezone.utc),
                 ),
                 routing_key=routing_key,
             )
@@ -350,7 +353,7 @@ class TCPBaseActor(BaseActor):
 
     def new_command(self, transport: CustomTransportType, command_str: bytes):
         """Handles a new command received by the actor."""
-        print("hellow")
+
         commander_id: Optional[int] = getattr(transport, "user_id", None)
         message: str = command_str.decode().strip()
 
