@@ -13,7 +13,7 @@ import logging
 import pathlib
 import warnings
 
-from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar, Union, cast
+from typing import Any, Dict, List, Optional, Tuple, TypeVar, Union, cast
 
 import click
 
@@ -27,7 +27,6 @@ from ..parsers import ClickParser
 from ..protocol import TCPStreamServer
 from ..tools import log_reply
 from .tron import TronConnection
-from .types.messages import Reply as OpsReply
 
 
 __all__ = ["LegacyActor", "BaseLegacyActor"]
@@ -125,7 +124,6 @@ class BaseLegacyActor(BaseActor):
         super().__init__(
             name,
             version=version,
-            loop=loop,
             log_dir=log_dir,
             log=log,
             verbose=verbose,
@@ -280,7 +278,7 @@ class BaseLegacyActor(BaseActor):
             return
 
         self.log.info(
-            f"New command received: {command_body   !r} "
+            f"New command received: {command_body!r} "
             f"(commander_id={commander_id!r}, command_id={command_id!r})"
         )
 
@@ -376,8 +374,7 @@ class BaseLegacyActor(BaseActor):
         commander: Optional[str] = None,
         command_id: Optional[int] = None,
         command: Optional[Command] = None,
-        callback: Optional[Callable[[OpsReply], None]] = None,
-        time_limit: Optional[float] = None,
+        **command_kwargs,
     ):
         """Sends a command through the hub.
 
@@ -396,10 +393,10 @@ class BaseLegacyActor(BaseActor):
             The command id. If `None`, a sequentially increasing value will
             be used. You should not specify a ``command_id`` unless you really
             know what you're doing.
-        callback
-            A callback to invoke with each reply received from the actor.
-        time_limit
-            A delay after which the command is marked as timed out and done.
+        command
+            A command from which to derive the commander ID.
+        command_kwargs
+            Additional keyword arguments to pass to the command.
 
         Examples
         --------
@@ -422,8 +419,7 @@ class BaseLegacyActor(BaseActor):
                 *args,
                 commander=commander,
                 mid=command_id,
-                callback=callback,
-                time_limit=time_limit,
+                **command_kwargs,
             )
             return command
 
@@ -490,7 +486,6 @@ class BaseLegacyActor(BaseActor):
             broadcast=broadcast,
             validate=validate,
             emit=False,
-            expand_exceptions=False,
             **kwargs,
         )
 
@@ -546,6 +541,17 @@ class BaseLegacyActor(BaseActor):
             command_id=command_id,
         )
 
+        # To prevent potential issues with how the actorkeys are defined, if the
+        # error or exception keywords are a dictionary (this means that they have
+        # information about the traceback, line number, etc.) we move that information
+        # to the "exception_info" keyword and leave the error/exception as just the
+        # error message. In the actorkeys for the actor there should be a keyword like
+        # Key("exception_info", String() * (0,), help="Exception information").
+        for keyword in ["error", "exception"]:
+            if keyword in message and isinstance(message[keyword], dict):
+                message["exception_info"] = message[keyword].copy()
+                message[keyword] = message[keyword].get("message", "")
+
         lines = []
         for keyword in message:
             try:
